@@ -27,7 +27,7 @@
 #include <lib/document.h>
 #include <lib/window.h>
 
-typedef struct _GOGChemPaintComponent
+struct _GOGChemPaintComponent
 {
 	GOComponent parent;
 
