@@ -32,9 +32,8 @@ public:
 	gcpGOfficeWindow (gcpGOfficeApplication *App, GOGChemPaintComponent *gogcp);
 	virtual ~gcpGOfficeWindow ();
 
-	virtual void OnSave ();
-	virtual void PopulateUI ();
-	virtual char const *GetDefaultTitle ();
+	void OnSave ();
+	char const *GetDefaultTitle ();
 
 private:
 	GOGChemPaintComponent *m_gogcp;
