@@ -58,6 +58,7 @@
 #	include <fstream.h>
 #endif
 #include <clocale>
+#include <cstring>
 
 // following code is needed to get file extensions, it as been essentially copied from gnome-vfs
 static map<string, list<string> > globs;
@@ -262,7 +263,7 @@ gcpApplication::gcpApplication ():
 		}
 
 		// Initialize types
-		Object::AddType ("molecule", CreateMolecule, MoleculeType);
+		Object::AddType ("molecule", ::CreateMolecule, MoleculeType);
 		Object::AddType ("reaction", CreateReaction, ReactionType);
 		Object::SetCreationLabel (ReactionType, _("Create a new reaction"));
 		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
@@ -338,6 +339,9 @@ gcpApplication::gcpApplication ():
 	GError *error = NULL;
 	GCU_GCONF_GET (ROOTDIR"compression", int, CompressionLevel, 0)
 	GCU_GCONF_GET (ROOTDIR"tearable-mendeleiev", bool, TearableMendeleiev, false)
+	bool CopyAsText;
+	GCU_GCONF_GET (ROOTDIR"copy-as-text", bool, CopyAsText, false)
+	ClipboardFormats = CopyAsText? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
 	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchempaint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
 	// make themes permanent with this as a dummy client
 	list <string> Names = ThemeManager.GetThemesNames ();
@@ -456,9 +460,11 @@ bool gcpApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		}
 	}
 	if (file_type < 0 || (!bSave && (file_type > CHEMISTRY))) {
+		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, filename);
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-													_("Sorry, format not supported!"));
+													mess);
 		gtk_dialog_run (GTK_DIALOG (message));
+		g_free (mess);
 		gtk_widget_destroy (message);
 		return true;
 	}
@@ -557,7 +563,7 @@ void gcpApplication::SaveWithBabel (string const &filename, const gchar *mime_ty
 void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_type, gcpDocument* pDoc)
 {
 	char *old_num_locale;
-	bool bNew = (pDoc == NULL || (!pDoc->GetEmpty () && ! pDoc->GetDirty ())), local;
+	bool bNew = (pDoc == NULL || !pDoc->GetEmpty () || pDoc->GetDirty ()), local;
 	GnomeVFSFileInfo *info = NULL;
 	bool result = false, read_only = false;
 	try {
@@ -621,9 +627,9 @@ void gcpApplication::OpenWithBabel (string const &filename, const gchar *mime_ty
 			g_free (old_num_locale);
 			g_free (buf);
 		}
-		if (!result)
-		{
-			if (bNew) delete pDoc;
+		if (!result) {
+			if (bNew)
+				pDoc->GetWindow ()->Destroy ();
 			throw (int) 2;
 		}
 		pDoc->SetFileName (filename, mime_type);
@@ -748,7 +754,7 @@ void gcpApplication::OpenGcp (string const &filename, gcpDocument* pDoc)
 		g_free(old_time_locale);
 		if (!result) {
 			if (create)
-				delete pDoc;
+				pDoc->GetWindow ()->Destroy ();
 			throw (int) 4;
 		}
 		if (!(info->permissions & (GNOME_VFS_PERM_USER_WRITE | GNOME_VFS_PERM_GROUP_WRITE)))
@@ -995,7 +1001,8 @@ void gcpApplication::OnConfigChanged (GConfClient *client, guint cnxn_id, GConfE
 		gcpTools *Tools = dynamic_cast<gcpTools*> (GetDialog ("tools"));
 		if (Tools)
 			Tools->Update ();
-	}
+	} else 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"copy-as-text"))
+		ClipboardFormats = (gconf_value_get_bool (gconf_entry_get_value (entry)))? GCP_CLIPBOARD_ALL: GCP_CLIPBOARD_NO_TEXT;
 }
 
 void gcpApplication::TestSupportedType (char const *mime_type)
