@@ -40,6 +40,7 @@
 #include <openbabel/mol.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
+#include <cstring>
 
 using namespace gcu;
 
@@ -322,6 +323,8 @@ void gcpAtom::Add (GtkWidget* w)
 	if (m_Changed > 0)
 		m_Changed--;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpView* pView = pData->View;
 	gcpTheme *pTheme = pView->GetDoc ()->GetTheme ();
 	if (m_Layout == NULL) {
@@ -586,6 +589,8 @@ void gcpAtom::Update(GtkWidget* w)
 {
 	if (!w) return;
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] == NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y, xc = 0., yc;
 	GetCoords(&x, &y);
@@ -1534,7 +1539,7 @@ xmlNodePtr gcpAtom::Save (xmlDocPtr xml)
 		xmlNewProp (node, (xmlChar*) "show-symbol", (xmlChar*) "true");
 	}
 	if (m_HPosStyle != AUTO_HPOS) {
-		xmlNewProp (node, (xmlChar*) "H-positon",
+		xmlNewProp (node, (xmlChar*) "H-position",
 					(xmlChar*) ((m_HPosStyle == LEFT_HPOS)? "left": "right"));
 	}
 	return node;
@@ -1618,6 +1623,7 @@ bool gcpAtom::Load (xmlNodePtr node)
 		else if (!strcmp (buf, "right"))
 			m_HPosStyle = RIGHT_HPOS;
 		xmlFree (buf);
+		Update ();
 	}
 	return true;
 }
