@@ -28,6 +28,7 @@
 #include <map>
 #include <glib.h>
 #include <gcu/atom.h>
+#include <gcu/dialog-owner.h>
 #include <gcu/element.h>
 #include <gcu/macros.h>
 #include <libgnomecanvas/gnome-canvas.h>
@@ -64,9 +65,15 @@ class gcpMolecule;
 #define POSITION_E 64
 #define POSITION_W 128
 
+enum {
+	LEFT_HPOS,
+	RIGHT_HPOS,
+	AUTO_HPOS,
+};
+
 class gcpElectron;
 
-class gcpAtom: public Atom
+class gcpAtom: public Atom, public DialogOwner
 {
 public:
 	gcpAtom();
@@ -96,7 +103,7 @@ public :
 	virtual bool AcceptCharge (int charge);
 	virtual double GetYAlign ();
 	virtual void Transform2D (Matrix2D& m, double x, double y);
-	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
 	/*!
 	@param Mol: a pointer to a molecule
 
@@ -106,6 +113,7 @@ public :
 	bool HasImplicitElectronPairs ();
 	bool MayHaveImplicitUnpairedElectrons ();
 	void AddElectron (gcpElectron* electron);
+	void RemoveElectron (gcpElectron* electron);
 	void NotifyPositionOccupation (unsigned char pos, bool occupied);
 	void SetChargePosition (unsigned char Pos, bool def, double angle = 0., double distance = 0.);
 	char GetChargePosition (double *Angle, double *Dist);
@@ -148,6 +156,7 @@ private:
 	string m_FontName;
 
 GCU_PROP (bool, ShowSymbol)
+GCU_PROP (unsigned char, HPosStyle) //0=force left, 1=force right, 2=auto.
 };
 
 #endif // GCHEMPAINT_ATOM_H
