@@ -37,7 +37,8 @@
 #include "libgcpcanvas/gcp-canvas-bpath.h"
 #include "libgcpcanvas/gcp-canvas-polygon.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
+#include <cmath>
+#include <cstring>
 
 gcpBond::gcpBond(): Bond()
 {
@@ -412,6 +413,8 @@ void gcpBond::Add(GtkWidget* w)
 {
 	if (!w) return;
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	Atom *pAtom0, *pAtom1;
 	if (!(pAtom0 = GetAtom(0))) return; 
@@ -713,6 +716,8 @@ void gcpBond::Update(GtkWidget* w)
 	if (!w || !m_order)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data(G_OBJECT(w), "data");
+	if (pData->Items[this] == NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	bool result = false;
 	if (m_Crossing.size () > 0) {
@@ -837,10 +842,14 @@ static void on_move_to_back (gcpBond *pBond)
 	pBond->MoveToBack ();
 }
 
-bool gcpBond::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpBond::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
+	bool result = false;
+	Object *pAtom = GetAtomAt (x, y);
+	if (pAtom)
+		result = pAtom->BuildContextualMenu (UIManager, object, x, y);
 	if (m_Crossing.size () == 0)
-		return GetParent ()->BuildContextualMenu (UIManager, object);;
+		return (pAtom)? result: GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	bool is_before = false, is_after = false;
 	if (m_Crossing.size () > 0) {
 		map<gcpBond*, gcpBondCrossing>::iterator i, iend = m_Crossing.end ();
@@ -854,25 +863,30 @@ bool gcpBond::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
 		}
 	}
 	if (!(is_before || is_after))
-		return GetParent ()->BuildContextualMenu (UIManager, object);;
+		return (pAtom)? result: GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	GtkActionGroup *group = gtk_action_group_new ("bond");
 	GtkAction *action;
 	action = gtk_action_new ("Bond", _("Bond"), NULL, NULL);
 	gtk_action_group_add_action (group, action);
+	g_object_unref (action);
 	if (is_before) {
 		action = gtk_action_new ("MoveBack", _("Move to back"), NULL, NULL);
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (on_move_to_back), this);
 		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
 		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Bond'><menuitem action='MoveBack'/></menu></popup></ui>", -1, NULL);
 	}
 	if (is_after) {
 		action = gtk_action_new ("BringFront", _("Bring to front"), NULL, NULL);
 		g_signal_connect_swapped (action, "activate", G_CALLBACK (on_bring_to_front), this);
 		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
 		gtk_ui_manager_add_ui_from_string (UIManager, "<ui><popup><menu action='Bond'><menuitem action='BringFront'/></menu></popup></ui>", -1, NULL);
 	}
 	gtk_ui_manager_insert_action_group (UIManager, group, 0);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	g_object_unref (group);
+	if (!pAtom)
+		GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
