@@ -4,9 +4,7 @@
  * GChemPaint library
  * bond.h 
  *
- * Copyright (C) 2001-2004
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -40,6 +38,11 @@ typedef enum
 	UndeterminedBondType
 } gcpBondType;
 
+typedef struct {
+	double a;
+	bool is_before;
+} gcpBondCrossing;
+	
 using namespace gcu;
 
 class gcpAtom;
@@ -80,16 +83,22 @@ public:
 	void Add(GtkWidget* w);
 	bool ReplaceAtom(gcpAtom* oldAtom, gcpAtom* newAtom);
 	virtual double GetYAlign ();
+	bool IsCrossing (gcpBond *pBond);
+	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
+	void MoveToBack ();
+	void BringToFront ();
 
 private:
 	GnomeCanvasPathDef* BuildPathDef (gcpWidgetData* pData);
+	GnomeCanvasPathDef* BuildCrossingPathDef (gcpWidgetData* pData);
 
 protected:
 	gcpBondType m_type;
 	double m_coords[16];//coordinates of the lines used to represent the bond in the canvas
 	bool m_CoordsCalc; //true if m_coords have been calculated, false else
 	list<gcpCycle*> m_Cycles;
+	map<gcpBond*, gcpBondCrossing> m_Crossing;
+	int m_level; // to know which bond shouldbe considered front
 };
 
-
 #endif // GCHEMPAINT_BOND_H
