@@ -4,7 +4,7 @@
  * GChemPaint library
  * docprop.h 
  *
- * Copyright (C) 2002-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,18 +26,26 @@
 #define GCHEMPAINT_DOC_PROP_H
 
 #include <gcu/dialog.h>
+#include <gcu/object.h>
+#include <gcu/macros.h>
 
 using namespace gcu;
 
 class gcpDocument;
+class gcpTheme;
 
-class gcpDocPropDlg: public Dialog
+class gcpDocPropDlg: public Dialog, Object
 {
 public:
 	gcpDocPropDlg (gcpDocument* pDoc);
 	virtual ~gcpDocPropDlg ();
 	
-	virtual bool Apply ();
+	void OnThemeNamesChanged ();
+	void OnThemeChanged (gcpTheme *theme);
+	void OnTitleChanged (char const *title);
+	void OnNameChanged (char const *title);
+	void OnMailChanged (char const *title);
+	void OnCommentsChanged (char const *title);
 	
 private:
 	gcpDocument* m_pDoc;
@@ -45,6 +53,11 @@ private:
 	GtkLabel *CreationDate, *RevisionDate;
 	GtkTextView *Comments;
 	GtkTextBuffer *Buffer;
+	GtkComboBox *m_Box;
+	unsigned m_Lines;
+	gulong m_ChangedSignal;
+
+GCU_PROP (gcpTheme*, Theme)
 };
 
 #endif //GCHEMPAINT_DOC_PROP_H
