@@ -33,6 +33,7 @@
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <set>
+#include <cstring>
 
 gcpMesomery::gcpMesomery (): Object (MesomeryType)
 {
@@ -773,9 +774,11 @@ double gcpMesomery::GetYAlign ()
 	Object *pObj;
 	pObj = GetFirstChild (i);
 	double y = DBL_MAX, new_y;
-	while (pObj)
+	while (pObj) {
 		if (pObj->GetType () == MesomerType)
 			if ((new_y = pObj->GetYAlign ()) < y)
-				y = new_y;			
+				y = new_y;
+		pObj = GetNextChild (i);
+	}
 	return y;
 }
