@@ -4,7 +4,7 @@
  * GChemPaint library
  * molecule.h 
  *
- * Copyright (C) 2001-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -36,6 +36,7 @@ public:
 	gcpMolecule(TypeId Type = MoleculeType);
 	gcpMolecule(gcpAtom* pAtom);
 	virtual ~gcpMolecule();
+	void Add (GtkWidget* w);
 	void AddAtom(gcpAtom* pAtom);
 	void AddFragment(gcpFragment* pFragment);
 	void AddBond(gcpBond* pBond);
@@ -50,7 +51,7 @@ public:
 	virtual void Transform2D(Matrix2D& m, double x, double y);
 	virtual Object* GetAtomAt(double x, double y, double z = 0.);
 	virtual double GetYAlign ();
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 	void ExportToGhemical ();
 	void SelectAlignmentItem (Object *child);
@@ -60,7 +61,7 @@ public:
 	void ShowInChI ();
 	void BuildInChI ();
 	void BuildSmiles ();
-	void ShowWebbook ();
+	void ShowWebBase (char const *uri_start, char const *uri_end);
 	void OpenCalc ();
 	void CheckCrossings (gcpBond *pBond);
 
