@@ -25,12 +25,14 @@
 #include "gchempaint-config.h"
 #include "operation.h"
 #include "document.h"
+#include <cstring>
 
 xmlDocPtr pXmlDoc = xmlNewDoc((const xmlChar*)"1.0");//Needed to create xmlNodes
 
-gcpOperation::gcpOperation(gcpDocument* pDoc)
+gcpOperation::gcpOperation(gcpDocument* pDoc, unsigned long ID):
+	m_pDoc (pDoc),
+	m_ID (ID)
 {
-	m_pDoc = pDoc;
 }
 
 gcpOperation::~gcpOperation()
@@ -72,7 +74,7 @@ void gcpOperation::AddNode(xmlNodePtr node, unsigned type)
 	if (node) xmlAddChild(m_Nodes[type], node);
 }
 
-gcpAddOperation::gcpAddOperation(gcpDocument* pDoc): gcpOperation(pDoc)
+gcpAddOperation::gcpAddOperation(gcpDocument* pDoc, unsigned long ID): gcpOperation(pDoc, ID)
 {
 	m_Nodes = new xmlNodePtr[1];
 	*m_Nodes = xmlNewDocNode(pXmlDoc, NULL, (const xmlChar*)"add", NULL);
@@ -93,7 +95,7 @@ void gcpAddOperation::Redo()
 	Add();
 }
 
-gcpDeleteOperation::gcpDeleteOperation(gcpDocument* pDoc): gcpOperation(pDoc)
+gcpDeleteOperation::gcpDeleteOperation(gcpDocument* pDoc, unsigned long ID): gcpOperation(pDoc, ID)
 {
 	m_Nodes = new xmlNodePtr[1];
 	*m_Nodes = xmlNewDocNode(pXmlDoc, NULL, (const xmlChar*)"delete", NULL);
@@ -114,7 +116,7 @@ void gcpDeleteOperation::Redo()
 	Delete();
 }
 
-gcpModifyOperation::gcpModifyOperation(gcpDocument* pDoc): gcpOperation(pDoc)
+gcpModifyOperation::gcpModifyOperation(gcpDocument* pDoc, unsigned long ID): gcpOperation(pDoc, ID)
 {
 	m_Nodes = new xmlNodePtr[2];
 	m_Nodes[0] = xmlNewDocNode(pXmlDoc, NULL, (const xmlChar*)"before", NULL);
