@@ -26,6 +26,7 @@
 #ifndef GCHEMPAINT_OPERATION_H
 #define GCHEMPAINT_OPERATION_H
 
+#include <gcu/macros.h>
 #include <gcu/object.h>
 
 using namespace gcu; 
@@ -42,7 +43,7 @@ typedef enum
 class gcpOperation
 {
 public:
-	gcpOperation(gcpDocument *pDoc);
+	gcpOperation(gcpDocument *pDoc, unsigned long ID);
 	virtual ~gcpOperation();
 
 	virtual void Undo();
@@ -57,12 +58,14 @@ protected:
 protected:
 	gcpDocument* m_pDoc;
 	xmlNodePtr* m_Nodes;
+
+GCU_RO_PROP (unsigned long, ID);
 };
 
 class gcpAddOperation: public gcpOperation
 {
 public:
-	gcpAddOperation(gcpDocument *pDoc);
+	gcpAddOperation(gcpDocument *pDoc, unsigned long ID);
 	virtual ~gcpAddOperation();
 
 	virtual void Undo();
@@ -72,7 +75,7 @@ public:
 class gcpDeleteOperation: public gcpOperation
 {
 public:
-	gcpDeleteOperation(gcpDocument *pDoc);
+	gcpDeleteOperation(gcpDocument *pDoc, unsigned long ID);
 	virtual ~gcpDeleteOperation();
 
 	virtual void Undo();
@@ -82,7 +85,7 @@ public:
 class gcpModifyOperation: public gcpOperation
 {
 public:
-	gcpModifyOperation(gcpDocument *pDoc);
+	gcpModifyOperation(gcpDocument *pDoc, unsigned long ID);
 	virtual ~gcpModifyOperation();
 
 	virtual void Undo();
