@@ -46,7 +46,7 @@ void gcpPlugin::LoadPlugins ()
 	if (dir ==  NULL) return;
 	const char* name;
 	while ((name = g_dir_read_name (dir))) {
-		if ((strcmp (name + strlen (name) - 3, ".so")))
+		if ((strcmp (name + strlen (name) - strlen ("."G_MODULE_SUFFIX), "."G_MODULE_SUFFIX)))
 			continue;
 		name = g_strconcat (PLUGINSDIR"/", name, NULL);
 		if (!dlopen (name, RTLD_NOW)) puts (dlerror());
