@@ -30,6 +30,7 @@
 #include "text.h"
 #include "theme.h"
 #include <glib/gi18n-lib.h>
+#include <cstring>
 
 extern xmlDocPtr pXmlDoc;
 
@@ -71,7 +72,9 @@ bool gcpReactant::BuildContextualMenu (GtkUIManager *UIManager, Object *object,
 		GtkActionGroup *group = gtk_action_group_new ("reactant");
 		GtkAction *action = gtk_action_new ("stoichiometry", _("Add a stoichiometry coefficient"), NULL, NULL);
 		gtk_action_group_add_action (group, action);
+		g_object_unref (action);
 		gtk_ui_manager_insert_action_group (UIManager, group, 0);
+		g_object_unref (group);
 		char buf[] = "<ui><popup><menuitem action='stoichiometry'/></popup></ui>";
 		gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 		GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/stoichiometry");
