@@ -33,6 +33,7 @@
 #include "libgcpcanvas/gcp-canvas-rect-ellipse.h"
 #include "libgcpcanvas/gcp-canvas-pango.h"
 #include <cmath>
+#include <cstring>
 
 gcpReactionOperator::gcpReactionOperator (): Object (ReactionOperatorType)
 {
@@ -47,6 +48,8 @@ void gcpReactionOperator::Add (GtkWidget* w)
 	if (!w)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] != NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y;
 	GetCoords (&x, &y);
@@ -99,6 +102,8 @@ void gcpReactionOperator::Update (GtkWidget* w)
 	if (!w)
 		return;
 	gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	if (pData->Items[this] == NULL)
+		return;
 	gcpTheme *pTheme = pData->View->GetDoc ()->GetTheme ();
 	double x, y;
 	GetCoords (&x, &y);
