@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction.h 
  *
- * Copyright (C) 2002-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -36,10 +36,9 @@ public:
 	gcpReaction ();
 	virtual ~gcpReaction ();
 	
-	virtual void Add ( GtkWidget* w);
 	virtual bool Build (list<Object*>& Children) throw (invalid_argument);
 	virtual void Transform2D (Matrix2D& m, double x, double y);
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 	virtual bool Load (xmlNodePtr);
 	virtual double GetYAlign ();
