@@ -24,11 +24,12 @@
 
 #include "gchempaint-config.h"
 #include "settings.h"
-gchar *Color = "black";
-gchar *DeleteColor = "red";
-gchar *AddColor = "green";
-gchar *SelectColor = "cyan";
+gchar *Color = (char*) "black";
+gchar *DeleteColor = (char*) "red";
+gchar *AddColor = (char*) "green";
+gchar *SelectColor = (char*) "cyan";
 unsigned MaxStackSize = 0;//infinite size authorized for undo:redo stacks
 bool MergeAtoms = true;
 int CompressionLevel = 0;
 bool TearableMendeleiev = false;
+int ClipboardFormats = GCP_CLIPBOARD_NO_TEXT;
