@@ -30,6 +30,7 @@
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n-lib.h>
+#include <cstring>
 
 static GtkTargetEntry const stargets[] = {
 	{(char *)"STRING", 0, 0}
@@ -49,7 +50,7 @@ static void on_string_clear_data(GtkClipboard *clipboard, gcpStringDlg *dlg)
 {
 }
 
-gcpStringDlg::gcpStringDlg (gcpDocument *pDoc, string& data, enum data_type type): Dialog (pDoc->GetApplication(), DATADIR"/gchempaint-unstable/ui/stringdlg.glade", "string")
+gcpStringDlg::gcpStringDlg (gcpDocument *pDoc, string& data, enum data_type type): Dialog (pDoc->GetApplication(), GLADEDIR"/stringdlg.glade", "string")
 {
 	Data = data;
 	Type = type;
