@@ -29,6 +29,7 @@
 #include <glib/gi18n-lib.h>
 #include <sys/stat.h>
 #include <cmath>
+#include <cstring>
 
 double DefaultBondLength = 140.;
 double DefaultBondAngle = 120.;
@@ -218,8 +219,8 @@ gcpThemeManager::gcpThemeManager ()
 	GCU_GCONF_GET_N_TRANSFORM (ROOTDIR"text-font-size", float, DefaultTextFontSize, 12., set_fontsize)
 	m_NotificationId = gconf_client_notify_add (m_ConfClient, "/apps/gchempaint/settings", (GConfClientNotifyFunc) on_config_changed, this, NULL, NULL);
 	// Build default theme from settings
-	m_Themes["Default"] = m_Themes[_("Default")] = new gcpTheme ("Default");
-	m_Names.push_front (_("Default"));
+	m_Themes["GChemPaint"] = new gcpTheme ("GChemPaint");
+	m_Names.push_front ("GChemPaint");
 	// load global themes
 	string path = DATADIR;
 	path += "/gchempaint/themes";
@@ -230,6 +231,12 @@ gcpThemeManager::gcpThemeManager ()
 		path = szhome;
 	path += "/.gchempaint/themes";
 	ParseDir (path, LOCAL_THEME_TYPE);
+	gchar *default_theme  =NULL;
+	GCU_GCONF_GET_STRING (ROOTDIR"default-theme", default_theme, "GChemPaint");
+	m_DefaultTheme = m_Themes[default_theme];
+	g_free (default_theme);
+	if (!m_DefaultTheme)
+		m_DefaultTheme = m_Themes["GChemPaint"];
 }
 
 gcpThemeManager::~gcpThemeManager ()
@@ -279,11 +286,15 @@ gcpThemeManager::~gcpThemeManager ()
 
 gcpTheme *gcpThemeManager::GetTheme (char const *name)
 {
+	if (!strcmp (_(name), _("Default")))
+		return m_DefaultTheme;
 	return m_Themes[name];
 }
 
 gcpTheme *gcpThemeManager::GetTheme (string &name)
 {
+	if (name == "Default" || name == _("Default") )
+		return m_DefaultTheme;
 	return m_Themes[name.c_str ()];
 }
 
@@ -298,7 +309,7 @@ void gcpThemeManager::OnConfigChanged (GConfClient *client, guint cnxn_id, GConf
 		return;	// we might want an error message?
 	if (cnxn_id != m_NotificationId)
 		return;	// we might want an error message?
-	gcpTheme *Theme = m_Themes["Default"];
+	gcpTheme *Theme = m_Themes["GChemPaint"];
 	if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"bond-length")) {
 		DefaultBondLength = gconf_value_get_float (gconf_entry_get_value (entry));
 		Theme->m_BondLength = DefaultBondLength;
@@ -405,6 +416,11 @@ void gcpThemeManager::OnConfigChanged (GConfClient *client, guint cnxn_id, GConf
 	} else if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"text-font-size"))  {
 		DefaultTextFontSize = set_fontsize (gconf_value_get_float (gconf_entry_get_value (entry)));
 		Theme->m_TextFontSize = DefaultTextFontSize;
+	} else if (!strcmp (gconf_entry_get_key (entry),ROOTDIR"default-theme"))  {
+		char const *name = gconf_value_get_string (gconf_entry_get_value (entry));
+		gcpTheme *pTheme = m_Themes[name];
+		if (pTheme)
+			m_DefaultTheme = pTheme;
 	}
 }
 
@@ -508,8 +524,10 @@ void gcpThemeManager::ParseDir (string &path, ThemeType type)
 void gcpThemeManager::AddFileTheme (gcpTheme *theme, char const *label)
 {
 	string name = theme->GetName ().c_str ();
+	if (name == "Default")
+		name = "GChemPaint";
 	if (m_Themes.find (name) != m_Themes.end ()) {
-		name = string (label) + ":" + name;
+		name = string ((label)? label: _("Unknown")) + ":" + name;
 	}
 	m_Themes[name] = theme;
 	m_Names.push_back (name);
@@ -537,6 +555,14 @@ void gcpThemeManager::ChangeThemeName (gcpTheme *theme, char const *name)
 	m_Names.push_back (name);
 }
 
+void gcpThemeManager::SetDefaultTheme (char const *name)
+{
+	gcpTheme *pTheme = m_Themes[name];
+	if (pTheme) {
+		m_DefaultTheme = pTheme;
+	}
+}
+
 bool gcpTheme::Save (xmlDocPtr xml)
 {
 	xmlNodePtr node = xmlNewDocNode (xml, NULL, (xmlChar*) "theme", NULL);
