@@ -4,7 +4,7 @@
  * GChemPaint library
  * theme.h
  *
- * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -26,28 +26,47 @@
 #define GCHEMPAINT_THEME_H
 
 #include <gcu/macros.h>
+#include <gcu/object.h>
 #include <glib/gtypes.h>
 #include <pango/pango.h>
 #include <gconf/gconf-client.h>
+#include <libxml/tree.h>
 #include <list>
 #include <map>
 #include <string>
+#include <set>
 
 using namespace std;
+using namespace gcu;
+
+typedef enum {
+	DEFAULT_THEME_TYPE,
+	LOCAL_THEME_TYPE,
+	GLOBAL_THEME_TYPE,
+	FILE_THEME_TYPE
+} ThemeType;
 
 class gcpTheme
 {
 friend class gcpThemeManager;
+friend class gcpPrefsDlg;
 
 public:
-	gcpTheme (char const *name, char const *local_name);
+	gcpTheme (char const *name);
 	~gcpTheme ();
 
 	string &GetName () {return m_Name;}
+	bool Save (xmlDocPtr);
+	bool Load (xmlNodePtr);
+	bool operator== (const gcpTheme &theme);
+	void AddClient (Object *client) {m_Clients.insert (client);}
+	void RemoveClient (Object *client);
+	void NotifyChanged ();
 
 private:
 	string m_Name;
-	string m_LocalName;
+	set <Object*> m_Clients;
+	bool modified;
 
 GCU_RO_PROP (double, BondLength)
 GCU_RO_PROP (double, BondAngle)
@@ -68,9 +87,7 @@ GCU_RO_PROP (double, ArrowPadding)
 GCU_RO_PROP (double, StoichiometryPadding)
 GCU_RO_PROP (double, ObjectPadding)
 GCU_RO_PROP (double, SignPadding)
-GCU_RO_PROP (double, ChargeSignHeight)
 GCU_RO_PROP (double, ChargeSignSize)
-GCU_RO_PROP (double, ChargeYAlign)
 GCU_RO_PROP (gchar*, FontFamily)
 GCU_RO_PROP (PangoStyle, FontStyle)
 GCU_RO_PROP (PangoWeight, FontWeight)
@@ -83,6 +100,7 @@ GCU_RO_PROP (PangoWeight, TextFontWeight)
 GCU_RO_PROP (PangoVariant, TextFontVariant)
 GCU_RO_PROP (PangoStretch, TextFontStretch)
 GCU_RO_PROP (gint, TextFontSize)
+GCU_RO_PROP (ThemeType, ThemeType);
 };
 
 class gcpThemeManager
@@ -95,13 +113,22 @@ public:
 	gcpTheme *GetTheme (string &name);
 	list <string> const &GetThemesNames ();
 	void OnConfigChanged (GConfClient *client,  guint cnxn_id, GConfEntry *entry);
-	gcpTheme *CreateNewTheme ();
+	gcpTheme *CreateNewTheme (gcpTheme *theme = NULL);
+	void AddFileTheme (gcpTheme *theme, char const *label);
+	void RemoveFileTheme (gcpTheme *theme);
+	void ChangeThemeName (gcpTheme *theme, char const *name);
+	gcpTheme *GetDefaultTheme () {return m_DefaultTheme;}
+	void SetDefaultTheme (char const *name);
+
+private:
+	void ParseDir (string &path, ThemeType type);
 
 private:
 	map <string, gcpTheme*> m_Themes;
 	list <string> m_Names;
 	GConfClient *m_ConfClient;
 	guint m_NotificationId;
+	gcpTheme *m_DefaultTheme;
 };
 
 extern gcpThemeManager ThemeManager;
