@@ -4,9 +4,7 @@
  * GChemPaint library
  * tool.h 
  *
- * Copyright (C) 2001-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -57,7 +55,6 @@ public:
 	virtual bool OnRightButtonClicked (GtkUIManager *UIManager);
 	virtual void Activate ();
 	virtual bool Deactivate ();
-	virtual void SetOptions ();
 	virtual void OnChangeState ();
 	void OnKeyPressed (unsigned int code) {m_nState |= code; OnChangeState ();}
 	void OnKeyReleased (unsigned int code) {if (m_nState & code) m_nState -= code; OnChangeState ();}
@@ -72,6 +69,8 @@ public:
 	virtual bool OnUndo ();
 	virtual bool OnRedo ();
 	virtual void PushNode (xmlNodePtr node);
+	virtual GtkWidget *GetPropertyPage ();
+	virtual char const *GetHelpTag () {return "";}
 	
 protected:
 	gdouble m_x0, m_y0, m_x1, m_y1, m_x, m_y;
