@@ -4,7 +4,7 @@
  * GChemPaint
  * tools.h 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -44,12 +44,16 @@ public:
 	void OnSelectTool (gcpTool *tool);
 	void RegisterTool (GtkWidget *w);
 	void OnElementChanged (int Z);
+	void SetElement (int Z);
+	void Update (void);
+	void OnHelp ();
 
 private:
 	GtkUIManager *m_UIManager;
 	GtkBox *m_ButtonsBox;
 	map<gcpTool*, int> m_Pages;
 	GtkNotebook *m_Book;
+	gcpTool *m_Tool;
 };
 
 #endif // GCHEMPAINT_TOOLS_H
