@@ -29,6 +29,7 @@
 #include "document.h"
 #include "application.h"
 #include "tool.h"
+#include "tools.h"
 #include "text.h"
 #include "theme.h"
 #include "window.h"
@@ -48,6 +49,9 @@
 #else
 #	include <fstream.h>
 #endif
+#include <map>
+#include <string>
+#include <cstring>
 
 /*
 Derivation of a new widget from gnome_canvas with an event for updating canvas size
@@ -199,6 +203,7 @@ gcpView::gcpView (gcpDocument *pDoc, bool Embedded)
 	m_Dragging = false;
 	m_pWidget = NULL;
 	m_PangoContext = NULL;
+	m_CurObject = NULL;
 }
 
 gcpView::~gcpView ()
@@ -221,6 +226,7 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 	gcpTool* pActiveTool = App? App->GetActiveTool (): NULL;
 	if ((!m_pDoc->GetEditable ()) || (!pActiveTool))
 		return true;
+	m_CurObject = (item) ? (Object*) g_object_get_data (G_OBJECT (item), "object") : NULL;
 	if (item == (GnomeCanvasItem*)m_ActiveRichText)
 	{
 		GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS(((GTypeInstance*)item)->g_class);
@@ -248,6 +254,7 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 					if (pBond->GetDist(x / pTheme->GetZoomFactor (), y / pTheme->GetZoomFactor ()) < (pTheme->GetPadding () + pTheme->GetBondWidth () / 2) / pTheme->GetZoomFactor ())
 					{
 						item = GNOME_CANVAS_ITEM((*i).second);
+						m_CurObject = pBond;
 						break;
 					}
 				}
@@ -255,17 +262,18 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 			}
 		}
 	}
-	Object* Obj;
+	Object *pAtom;
+	if (m_CurObject && ((pAtom = m_CurObject->GetAtomAt (x / pTheme->GetZoomFactor (), y / pTheme->GetZoomFactor ()))))
+			m_CurObject = pAtom;
 	switch (event->type)
 	{
 	case GDK_BUTTON_PRESS:
-		Obj = (item) ? (Object*) g_object_get_data(G_OBJECT(item), "object") : NULL;
 		switch (event->button.button)
 		{
 			case 1:
 			{
 				if (m_Dragging) break;
-				bool result = pActiveTool->OnClicked(this, Obj, x, y, event->button.state);
+				bool result = pActiveTool->OnClicked(this, m_CurObject, x, y, event->button.state);
 				if (item && (item == (GnomeCanvasItem*)m_ActiveRichText))
 				{
 					GnomeCanvasItemClass* klass = GNOME_CANVAS_ITEM_CLASS(((GTypeInstance*)item)->g_class);
@@ -286,9 +294,9 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 				bool result;
 				g_object_unref (m_UIManager);
 			 	m_UIManager = gtk_ui_manager_new ();
-				result = pActiveTool->OnRightButtonClicked(this, Obj, event->button.x, event->button.y, m_UIManager);
-				if (Obj)
-					result |= Obj->BuildContextualMenu (m_UIManager, Obj, x / GetZoomFactor (), y / GetZoomFactor ());
+				result = pActiveTool->OnRightButtonClicked(this, m_CurObject, event->button.x, event->button.y, m_UIManager);
+				if (m_CurObject)
+					result |= m_CurObject->BuildContextualMenu (m_UIManager, m_CurObject, x / GetZoomFactor (), y / GetZoomFactor ());
 				if (result) {
 					GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
 					gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
@@ -539,8 +547,9 @@ GtkTargetEntry const targets[] = {
 	{(char *) "image/svg+xml",  0, 2},
 	{(char *) "image/png",  0, 3},
 	{(char *) "image/jpeg",  0, 4},
-	{(char *) "UTF8_STRING", 0, 1},
-	{(char *) "STRING", 0, 2}
+	{(char *) "image/bmp",  0, 5},
+	{(char *) "UTF8_STRING", 0, 6},
+	{(char *) "STRING", 0, 7}
 };
 
 void gcpView::OnCopySelection(GtkWidget* w, GtkClipboard* clipboard)
@@ -571,30 +580,28 @@ void gcpView::OnReceive(GtkClipboard* clipboard, GtkSelectionData* selection_dat
 	xmlDocPtr xml;
 	m_pData->UnselectAll();
 	switch (*DataType) {
-		case 0:
+		case GCP_CLIPBOARD_NATIVE:
 			xml = xmlParseMemory ((const char*) selection_data->data, selection_data->length);
 			m_pDoc->AddData (xml->children->children);
 			xmlFreeDoc (xml);
 			break;
-		case 5: {
+		case GCP_CLIPBOARD_UTF8_STRING: {
 				gcpText* text = new gcpText ();
-				PangoLayout *layout = text->GetLayout ();
-				pango_layout_set_text (layout, (const char*) selection_data->data, selection_data->length);
+				text->SetText ((char const*) selection_data->data);
 				text->OnChanged (true);
 				m_pDoc->AddObject (text);
 				m_pData->SetSelected (text);
 			}
 			break;
-		case 6: {
+		case GCP_CLIPBOARD_STRING: {
 				gcpText* text = new gcpText ();
-				PangoLayout *layout = text->GetLayout ();
 				if (!g_utf8_validate ((const char*) selection_data->data, selection_data->length, NULL)) {
 					gsize r, w;
 					gchar* newstr = g_locale_to_utf8 ((const char*) selection_data->data, selection_data->length, &r, &w, NULL);
-					pango_layout_set_text (layout, newstr, w);
+					text->SetText (newstr);
 					g_free (newstr);
 				} else
-					pango_layout_set_text (layout, (const char*) selection_data->data, selection_data->length);
+					text->SetText ((char const*) selection_data->data);
 				text->OnChanged (true);
 				m_pDoc->AddObject (text);
 				m_pData->SetSelected (text);
@@ -668,32 +675,193 @@ void gcpView::OnCutSelection(GtkWidget* w, GtkClipboard* clipboard)
 	Win->ActivateActionWidget ("/MainMenu/EditMenu/Erase", false);
 }
 
+static void do_set_symbol (GtkAction *action, Object *obj)
+{
+	gcpDocument* pDoc = static_cast<gcpDocument*> (obj->GetDocument ());
+	gcpApplication *App = static_cast<gcpApplication*> (pDoc->GetApplication ());
+	gcpTools *tools = static_cast<gcpTools*> (App->GetDialog ("tools"));
+	int Z = Element::Z (gtk_action_get_name(action));
+	tools->SetElement (Z);
+	if (obj->GetType () == AtomType) {
+		Atom *atom = static_cast<Atom*> (obj);
+		if (atom->GetZ () == Z)
+			return;
+		Object *group = obj->GetGroup ();
+		gcpOperation *op = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+		op->AddObject (group);
+		atom->SetZ (Z);
+		pDoc->GetView ()->Update (obj);
+		op->AddObject (group, 1);
+		pDoc->FinishOperation ();
+	}
+}
+
 bool gcpView::OnKeyPress(GtkWidget* w, GdkEventKey* event)
 {
 	gcpApplication*	pApp = m_pDoc->GetApplication();
 	gcpTool* pActiveTool = pApp->GetActiveTool();
-	if (pActiveTool->OnEvent((GdkEvent*)event)) return true;
-	switch(event->keyval)
-	{
-		case GDK_Delete:
-		case GDK_Clear:
-		case GDK_BackSpace:
-			OnDeleteSelection(w);
-			return true;
-		case GDK_Shift_L:
-		case GDK_Shift_R:
-			if (pActiveTool) pActiveTool->OnKeyPressed(GDK_SHIFT_MASK);
-			return true;
-		case GDK_Control_L:
-		case GDK_Control_R:
-			if (pActiveTool) pActiveTool->OnKeyPressed(GDK_CONTROL_MASK);
-			return true;
-		case GDK_Alt_L:
-		case GDK_Alt_R:
-			if (pActiveTool) pActiveTool->OnKeyPressed(GDK_MOD1_MASK);//FIXME: might be not portable
-			return true;
-		default:
+	if (pActiveTool->OnEvent ((GdkEvent*) event))
+		return true;
+	switch (event->keyval) {
+	case GDK_Delete:
+	case GDK_Clear:
+	case GDK_BackSpace:
+		OnDeleteSelection(w);
+		return true;
+	case GDK_Shift_L:
+	case GDK_Shift_R:
+		if (pActiveTool)
+			pActiveTool->OnKeyPressed (GDK_SHIFT_MASK);
+		return true;
+	case GDK_Control_L:
+	case GDK_Control_R:
+		if (pActiveTool)
+			pActiveTool->OnKeyPressed (GDK_CONTROL_MASK);
+		return true;
+	case GDK_Alt_L:
+	case GDK_Alt_R:
+		if (pActiveTool)
+			pActiveTool->OnKeyPressed (GDK_MOD1_MASK);//FIXME: might be not portable
+		return true;
+	default: {
+			if ((event->state & (GDK_CONTROL_MASK | GDK_MOD1_MASK)) != 0 || event->keyval > 127)
+				break;
+			// Now try to get the atom at the cursor
+			gcpAtom *atom = dynamic_cast<gcpAtom*> (m_CurObject);
+			unsigned min_bonds = (atom)? atom->GetTotalBondsNumber (): 0;
+			int Z = 0;
+			switch (event->keyval) {
+			case GDK_a:
+				Z = 13;
+				break;
+			case GDK_b:
+				Z = 5;
+				break;
+			case GDK_c:
+				Z = 6;
+				break;
+			case GDK_d:
+				Z = 11;
+				break;
+			case GDK_e:
+				Z = 34;
+				break;
+			case GDK_f:
+				Z = 9;
+				break;
+			case GDK_g:
+				Z = 32;
+				break;
+			case GDK_h:
+				Z = 1;
+				break;
+			case GDK_i:
+				Z = 53;
+				break;
+			case GDK_j:
+				Z = 22;
+				break;
+			case GDK_k:
+				Z = 19;
+				break;
+			case GDK_l:
+				Z = 3;
+				break;
+			case GDK_m:
+				Z = 12;
+				break;
+			case GDK_n:
+				Z = 7;
+				break;
+			case GDK_o:
+				Z = 8;
+				break;
+			case GDK_p:
+				Z = 15;
+				break;
+			case GDK_q:
+				Z = 14;
+				break;
+			case GDK_r:
+				Z = 35;
+				break;
+			case GDK_s:
+				Z = 16;
+				break;
+			case GDK_t:
+				Z = 78;
+				break;
+			case GDK_u:
+				Z = 29;
+				break;
+			case GDK_v:
+				Z = 23;
+				break;
+			case GDK_w:
+				Z = 74;
+				break;
+			case GDK_x:
+				Z = 17;
+				break;
+			case GDK_y:
+				Z = 39;
+				break;
+			case GDK_z:
+				Z = 40;
+				break;
+			}
+			if (Z) {
+				if (!atom) {
+					gcpTools *tools = static_cast<gcpTools*> (pApp->GetDialog ("tools"));
+					tools->SetElement (Z);
+				} else if (atom->GetZ () != Z && Element::GetElement (Z)->GetMaxBonds () >= min_bonds) {
+					Object *group = atom->GetGroup ();
+					gcpOperation *op = m_pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+					op->AddObject (group);
+					atom->SetZ (Z);
+					Update (atom);
+					op->AddObject (group, 1);
+					m_pDoc->FinishOperation ();
+				}
+				return true;
+			}
+			// build a contextual menu of all known symbols starting with the pressed key.
+			map<string, Element*> entries;
+			string symbol;
+			unsigned key = gdk_keyval_to_upper (event->keyval);
+			for (int i = 1; i <= 128; i++) {
+				Element *elt = Element::GetElement (i);
+				if (!elt || elt->GetMaxBonds () < min_bonds)
+					continue;
+				symbol = elt->GetSymbol ();
+				if ((unsigned char) symbol[0] == key) {
+					entries[symbol] = elt;
+				}
+			}
+			if (entries.empty ())
+				break;
+			map<string, Element*>::iterator i, end = entries.end ();
+			g_object_unref (m_UIManager);
+			m_UIManager = gtk_ui_manager_new ();
+			GtkActionGroup *group = gtk_action_group_new ("element");;
+			GtkAction *action;
+			string ui;
+			for (i = entries.begin (); i != end; i++) {
+				symbol = (*i).first;
+				symbol.insert (((symbol.length () > 1)? 1: 0), "_");
+				action = GTK_ACTION (gtk_action_new ((*i).second->GetSymbol (), symbol.c_str (), (*i).second->GetName (), NULL));
+				g_signal_connect (action, "activate", G_CALLBACK (do_set_symbol), (atom)? static_cast<Object*> (atom): static_cast<Object*> (m_pDoc));
+				gtk_action_group_add_action (group, action);
+				g_object_unref (action);
+				ui = string ("<ui><popup><menuitem action='") + (*i).second->GetSymbol () + "'/></popup></ui>";
+				gtk_ui_manager_add_ui_from_string (m_UIManager, ui.c_str (), -1, NULL);
+			}
+			gtk_ui_manager_insert_action_group (m_UIManager, group, 0);
+			g_object_unref (group);
+			GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "/popup");
+			gtk_menu_popup (GTK_MENU (w), NULL, NULL, NULL, NULL, 3,  gtk_get_current_event_time ());
 			break;
+		}
 	}
 	return false;
 }
@@ -978,28 +1146,7 @@ void gcpView::ExportImage (string const &filename, const char* type, int resolut
 		xmlSaveFormatFile (filename.c_str (), doc, true);
 		xmlFreeDoc (doc);
 	} else {
-		double zoom;
-		if (resolution > 0) {
-			int screenres = m_pDoc->GetApp ()->GetScreenResolution ();
-			zoom = (double) resolution / screenres;
-			w = (int) rint ((double) w * zoom);
-			h = (int) rint ((double) h * zoom);
-		} else
-			zoom = 1.;
-		gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), zoom);
-		gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
-		GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
-		gdk_pixbuf_fill (pixbuf, 0xffffffff);
-		GnomeCanvasBuf buf;
-		buf.buf = gdk_pixbuf_get_pixels (pixbuf);
-		buf.rect.x0 = (int) floor (rect.x0 * zoom);
-		buf.rect.x1 = (int) ceil (rect.x1 * zoom);
-		buf.rect.y0 = (int) floor (rect.y0 * zoom);
-		buf.rect.y1 = (int) ceil (rect.y1 * zoom);
-		buf.buf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
-		buf.bg_color = 0xffffff;
-		buf.is_buf = 1;
-		(* GNOME_CANVAS_ITEM_GET_CLASS (m_pData->Group)->render) (GNOME_CANVAS_ITEM (m_pData->Group), &buf);
+		GdkPixbuf *pixbuf = BuildPixbuf (resolution);
 		GnomeVFSHandle *handle = NULL;
 		if (gnome_vfs_create (&handle, filename.c_str (), GNOME_VFS_OPEN_WRITE, true, 0644) == GNOME_VFS_OK) {
 			GError *error = NULL;
@@ -1011,8 +1158,6 @@ void gcpView::ExportImage (string const &filename, const char* type, int resolut
 			gnome_vfs_close (handle); // hope there will be no error there
 		}
 		g_object_unref (pixbuf);
-		// restore zoom level
-		gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), m_pData->Zoom);
 	}
 	m_pData->ShowSelection (true);
 }
@@ -1067,6 +1212,39 @@ xmlDocPtr gcpView::BuildSVG ()
 	return doc;
 }
 
+GdkPixbuf *gcpView::BuildPixbuf (int resolution)
+{
+	ArtDRect rect;
+	m_pData->GetObjectBounds (m_pDoc, &rect);
+	m_pData->ShowSelection (false);
+	int w = (int) (ceil (rect.x1) - floor (rect.x0)), h = (int) (ceil (rect.y1) - floor (rect.y0));
+	double zoom;
+	if (resolution > 0) {
+		int screenres = m_pDoc->GetApp ()->GetScreenResolution ();
+		zoom = (double) resolution / screenres;
+		w = (int) rint ((double) w * zoom);
+		h = (int) rint ((double) h * zoom);
+	} else
+		zoom = 1.;
+	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), zoom);
+	gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
+	GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+	gdk_pixbuf_fill (pixbuf, 0xffffffff);
+	GnomeCanvasBuf buf;
+	buf.buf = gdk_pixbuf_get_pixels (pixbuf);
+	buf.rect.x0 = (int) floor (rect.x0 * zoom);
+	buf.rect.x1 = (int) ceil (rect.x1 * zoom);
+	buf.rect.y0 = (int) floor (rect.y0 * zoom);
+	buf.rect.y1 = (int) ceil (rect.y1 * zoom);
+	buf.buf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+	buf.bg_color = 0xffffff;
+	buf.is_buf = 1;
+	(* GNOME_CANVAS_ITEM_GET_CLASS (m_pData->Group)->render) (GNOME_CANVAS_ITEM (m_pData->Group), &buf);
+	// restore zoom level
+	gnome_canvas_set_pixels_per_unit (GNOME_CANVAS (m_pWidget), m_pData->Zoom);
+	return pixbuf;
+}
+
 void gcpView::EnsureSize ()
 {
 	GnomeCanvas *canvas = GNOME_CANVAS (m_pWidget);
