@@ -229,12 +229,12 @@ static void on_help (GtkWidget *widget, gcpWindow* Win)
 
 static void on_web (GtkWidget *widget, gcpWindow* Win)
 {
-	Win->GetApplication ()->OnWeb ("gchempaint.nongnu.org");
+	Win->GetApplication ()->OnWeb ((char*) "gchempaint.nongnu.org");
 }
 
 static void on_mail (GtkWidget *widget, gcpWindow* Win)
 {
-	Win->GetApplication ()->OnMail ("mailto:gchempaint-main@nongnu.org");
+	Win->GetApplication ()->OnMail ((char*) "mailto:gchempaint-main@nongnu.org");
 }
 
 static void on_bug (GtkWidget *widget, gcpWindow* Win)
@@ -501,6 +501,7 @@ gcpWindow::gcpWindow (gcpApplication *App, char const *Theme, char const *extra_
 		"signal::disconnect_proxy", G_CALLBACK (on_disconnect_proxy), this,
 		NULL);
 	gtk_ui_manager_insert_action_group (m_UIManager, action_group, 0);
+	g_object_unref (action_group);
 
 	accel_group = gtk_ui_manager_get_accel_group (m_UIManager);
 	gtk_window_add_accel_group (GTK_WINDOW (m_Window), accel_group);
