@@ -4,9 +4,7 @@
  * GChemPaint library
  * zoomdlg.h
  *
- * Copyright (C) 2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -32,19 +30,20 @@
 
 using namespace gcu;
 
-class gcpApplication;
+class gcpDocument;
 
 class gcpZoomDlg: public Dialog
 {
 public:
-	gcpZoomDlg (gcpApplication* pApp);
+	gcpZoomDlg (gcpDocument* pDoc);
 	virtual ~gcpZoomDlg ();
 	
-	virtual bool Apply ();
 	void OnFocusIn ();
 	
 private:
 	GtkSpinButton *btn;
+	gcpDocument *m_Doc;
+	gulong m_ZoomSignal;
 };
 
 #endif //GCHEMPAINT_ZOOM_DLG_H
