@@ -1019,6 +1019,7 @@ gnome_canvas_pango_button_press_event (GnomeCanvasItem *item,
 	}
 	pango_layout_xy_to_index (text->_priv->layout, newx * PANGO_SCALE,
 		newy * PANGO_SCALE, &index, &trailing);
+	index += trailing;
 	if (index >= sel_start && index <= sel_end) {
 		/* TODO: start drag and drop, at the moment, just position the cursor */
 		text->_priv->index = text->_priv->start_sel = index;
@@ -1057,6 +1058,7 @@ gnome_canvas_pango_drag_event (GnomeCanvasItem *item,
 	newy = (event->y - text->_priv->y) * item->canvas->pixels_per_unit;
 	pango_layout_xy_to_index (text->_priv->layout, newx * PANGO_SCALE,
 		newy * PANGO_SCALE, &text->_priv->index, &trailing);
+	text->_priv->index += trailing;
 	gnome_canvas_pango_update_line_pos (text);
 	gnome_canvas_item_request_update (GNOME_CANVAS_ITEM (text));
 	/* TODO: implement DnD */
