@@ -36,23 +36,26 @@ void pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl)
 	const char *text = pango_layout_get_text (pl);
 	int w1, w2, h1, h2, l;
 	double zoom, extra_space;
+	PangoFontDescription const *desc = pango_layout_get_font_description (pl);
+	PangoAttribute *pa;
+	PangoAttrList *pal = (attrs)? pango_attr_list_copy (attrs): pango_attr_list_new ();
 	l = strlen (text);
 	pango_layout_set_text (layout, text, l);
-	pango_layout_set_attributes (layout, attrs);
+	if (desc)
+		pango_layout_set_font_description (layout, desc);
+	pango_layout_set_attributes (layout, pal);
 	pango_layout_get_size (pl, &w1, &h1);
 	pango_layout_get_size (layout, &w2, &h2);
 	zoom = (double) h1 / (double) h2;
 	extra_space = w1 / zoom - w2;
 	if (l > 1) {
-		PangoAttribute *pa;
-		PangoAttrList *pal = pango_attr_list_copy (attrs);
 		pa = pango_attr_letter_spacing_new ((int) extra_space / l);
 		pa->start_index = 0;
 		pa->end_index = l;
 		pango_attr_list_insert (pal, pa);
 		pango_layout_set_attributes (layout, pal);
-		pango_attr_list_unref (pal);
 	}
+	pango_attr_list_unref (pal);
 	gnome_print_gsave (gpc);
 	gnome_print_scale (gpc, zoom, -zoom); /* not so good. Why is zoom necessary to get the same size ? Have a look at resolution */
 	gnome_print_moveto (gpc, 0., 0.);
