@@ -4,7 +4,7 @@
  * GChemPaint arrows plugin
  * arrowtool.h 
  *
- * Copyright (C) 2001-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -42,9 +42,11 @@ public:
 	bool OnClicked ();
 	void OnDrag ();
 	void OnRelease ();
-	void SetOptions ();
+	void Activate ();
 	void SetArrowType (unsigned ArrowType) {m_ArrowType = ArrowType;}
 	GtkWidget *GetPropertyPage ();
+	char const *GetHelpTag () {return "arrow";}
+	void SetLength (double length);
 
 protected:
 	GnomeCanvasPoints *points;
@@ -52,6 +54,7 @@ protected:
 private:
 	double m_dAngle;
 	unsigned m_ArrowType;
+	GtkSpinButton *m_LengthBtn;
 };
 
 #endif	//GCHEMPAINT_ARROW_TOOL_H
