@@ -67,8 +67,6 @@ static gcpIconDesc icon_descs[] = {
 	{"gcp_ReversibleArrow", gcp_arrow2_24},
 	{"gcp_RetrosynthesisArrow", gcp_retrosynth_24},
 	{"gcp_MesomeryArrow", gcp_mesomery_24},
-	{"gcp_CurvedArrow", gcp_curved_24},
-	{"gcp_Curved1Arrow", gcp_curved1_24},
 	{NULL, NULL},
 };
 
@@ -85,12 +83,6 @@ static GtkRadioActionEntry entries[] = {
 	{	"DoubleHeadedArrow", "gcp_MesomeryArrow", N_("Mesomery arrow"), NULL,
 		N_("Add a double headed arrow to represent mesomery"),
 		0	},
-	{	"CurvedArrow", "gcp_CurvedArrow", N_("Electron pair move arrow"), NULL,
-		N_("Add a curved arrow to represent an electron pair move"),
-		0	},
-	{	"Curved1Arrow", "gcp_Curved1Arrowd", N_("Single electron move arrow"), NULL,
-		N_("Add a curved arrow to represent an single electron move"),
-		0	},
 };
 
 static const char *ui_description =
@@ -100,8 +92,6 @@ static const char *ui_description =
 "    <toolitem action='ReversibleArrow'/>"
 "    <toolitem action='RetrosynthesisArrow'/>"
 "    <toolitem action='DoubleHeadedArrow'/>"
-//"    <toolitem action='CurvedArrow'/>"
-//"    <toolitem action='Curved1Arrow'/>"
 "  </toolbar>"
 "</ui>";
 
