@@ -31,13 +31,13 @@
 #include "lib/widgetdata.h"
 #include "lib/view.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
+#include <cmath>
 
 TypeId RetrosynthesisType = NoType;
 
 gcpRetrosynthesis::gcpRetrosynthesis (): Object (RetrosynthesisType)
 {
-	SetId ("rsy1");
+	SetId ((char*) "rsy1");
 	Target = NULL;
 }
 
@@ -280,8 +280,8 @@ int gcpRetrosynthesis::Validate (bool split)
 			return 2;
 		pObj = GetFirstChild (i);
 		while (pObj && (pObj->GetType () != RetrosynthesisStepType || 
-			(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow ()) ||
-			pObj == Target)
+			(reinterpret_cast<gcpRetrosynthesisStep *> (pObj))->GetArrow () ||
+			pObj == Target))
 			pObj = GetNextChild (i);
 		if (reinterpret_cast<gcpRetrosynthesisStep *> (pObj)->Validate ()) {
 			gcpRetrosynthesis *rs = new gcpRetrosynthesis (GetParent (), 
@@ -412,17 +412,19 @@ static void do_destroy_retrosynthesis (void *data)
 	pDoc->FinishOperation ();
 }
 
-bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+bool gcpRetrosynthesis::BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y)
 {
 	GtkActionGroup *group = gtk_action_group_new ("retrosynthesis");
 	GtkAction *action = gtk_action_new ("destroy-rs", _("Destroy the retrosynthesis path"), NULL, NULL);
 	gtk_action_group_add_action (group, action);
+	g_object_unref (action);
 	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	g_object_unref (group);
 	char buf[] = "<ui><popup><menuitem action='destroy-rs'/></popup></ui>";
 	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
 	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy-rs");
 	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_retrosynthesis), this);
-	GetParent ()->BuildContextualMenu (UIManager, object);
+	GetParent ()->BuildContextualMenu (UIManager, object, x, y);
 	return true;
 }
 
@@ -437,7 +439,7 @@ bool gcpRetrosynthesis::OnSignal (SignalId Signal, Object *Child)
 
 gcpRetrosynthesis::gcpRetrosynthesis (Object* parent, gcpRetrosynthesisStep *step): Object (RetrosynthesisType)
 {
-	SetId ("rsy1");
+	SetId ((char*) "rsy1");
 	SetParent (parent);
 	Target = step;
 	AddChild (Target);
