@@ -43,7 +43,7 @@ public:
 	virtual bool Load (xmlNodePtr);
 	virtual bool Build (list<Object*>& Children) throw (invalid_argument);
 	virtual double GetYAlign ();
-	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object);
+	virtual bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
 	virtual bool OnSignal (SignalId Signal, Object *Child);
 	virtual void Transform2D (Matrix2D& m, double x, double y);
 	int Validate (bool split);
