@@ -27,14 +27,20 @@
 #include "lib/settings.h"
 #include "lib/document.h"
 #include "lib/application.h"
+#include "lib/theme.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
+#include "libgcpcanvas/gcp-canvas-pango.h"
+#include <glib/gi18n-lib.h>
 #include <cmath>
 
 gcpChargeTool::gcpChargeTool(gcpApplication *App, string Id): gcpTool(App, Id)
 {
-	if (Id == string("ChargePlus")) m_glyph = const_cast<char*> ("\xE2\x8a\x95");
-	else if (Id == string("ChargeMinus")) m_glyph = const_cast<char*> ("\xE2\x8a\x96");
-	else m_glyph = 0;
+	if (Id == string ("ChargePlus"))
+		m_glyph = (char*) "\xE2\x8a\x95";
+	else if (Id == string ("ChargeMinus"))
+		m_glyph = (char*) "\xE2\x8a\x96";
+	else
+		m_glyph = 0;
 }
 
 gcpChargeTool::~gcpChargeTool()
@@ -46,6 +52,7 @@ bool gcpChargeTool::OnClicked()
 	if (!m_pObject || (m_pObject->GetType () != AtomType))
 		return false;
 	gcpAtom *pAtom = (gcpAtom*) m_pObject;
+	gcpTheme *Theme = m_pView->GetDoc ()->GetTheme ();
 	m_Charge = pAtom->GetCharge () + ((GetName() == string("ChargePlus"))? 1: -1);
 	if (!pAtom->AcceptCharge (m_Charge))
 		return false;
@@ -118,43 +125,43 @@ bool gcpChargeTool::OnClicked()
 			}
 		}
 		char* markup = NULL;
+		PangoLayout* pl = NULL;
 		if (abs (m_Charge) > 1) {
 			markup = g_strdup_printf ("%d", abs (m_Charge));
 			PangoContext* pc = m_pView->GetPangoContext();
 			PangoRectangle rect;
-			pango_context_set_font_description (pc, m_pView->GetPangoSmallFontDesc ());
-			PangoLayout* pl = pango_layout_new (pc);
+			pl = pango_layout_new (pc);
 			pango_layout_set_text (pl, markup, -1);
 			pango_layout_get_extents (pl, NULL, &rect);
 			m_ChargeWidth = rect.width / PANGO_SCALE;
-			pango_context_set_font_description (pc, m_pView->GetPangoFontDesc ());
-			m_ChargeTWidth = m_ChargeWidth + 1. + ChargeSignSize;
+			pango_layout_set_font_description (pl, m_pView->GetPangoSmallFontDesc ());
+			m_ChargeTWidth = m_ChargeWidth + 1. + Theme->GetChargeSignSize ();
 		} else {
 			m_ChargeWidth = 0.;
-			m_ChargeTWidth = ChargeSignSize;
+			m_ChargeTWidth = Theme->GetChargeSignSize ();
 		}
 		switch (align) {
 		case -2:
-			xc = x + m_ChargeTWidth / 2. - ChargeSignSize;
-			y += ChargeSignHeight / 2.;
+			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
+			y += Theme->GetChargeSignSize () / 2.;
 			break;
 		case -1:
-			xc = x - ChargeSignSize -1.;
+			xc = x - Theme->GetChargeSignSize () - Theme->GetPadding ();
 			break;
 		case 0:
 		case -3:
-			xc = x + m_ChargeTWidth / 2. - ChargeSignSize;
+			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
 			break;
 		case 1:
-			xc = x + m_ChargeWidth + 1.;
+			xc = x + m_ChargeWidth + Theme->GetPadding ();
 			break;
 		case 2:
-			xc = x + m_ChargeTWidth / 2. - ChargeSignSize;
-			y -= ChargeSignHeight / 2.;
+			xc = x + m_ChargeTWidth / 2. - Theme->GetChargeSignSize ();
+			y -= Theme->GetChargeSignSize () / 2.;
 			break;
 		}
 		x = xc - 1.;
-		yc = y - ChargeSignHeight / 2. + ChargeYAlign - ChargeSignSize + 1.;
+		yc = y - Theme->GetChargeSignSize () / 2.;
 		m_x1 = x;
 		m_y1 = y;
 		m_pItem = gnome_canvas_item_new (
@@ -164,10 +171,9 @@ bool gcpChargeTool::OnClicked()
 		if (markup) {
 			gnome_canvas_item_new(
 						GNOME_CANVAS_GROUP (m_pItem),
-						gnome_canvas_text_get_type(),
+						gnome_canvas_pango_get_type(),
 						"fill_color", AddColor,
-						"font-desc", m_pView->GetPangoSmallFontDesc (),
-						"markup", markup,
+						"layout", pl,
 						"anchor", GTK_ANCHOR_EAST,
 						"x", x,
 						"y", y,
@@ -178,8 +184,8 @@ bool gcpChargeTool::OnClicked()
 					gnome_canvas_ellipse_get_type (),
 					"x1", xc,
 					"y1", yc,
-					"x2", xc + ChargeSignSize,
-					"y2", yc + ChargeSignSize,
+					"x2", xc + Theme->GetChargeSignSize (),
+					"y2", yc + Theme->GetChargeSignSize (),
 					"outline_color", AddColor,
 					"width_units", 0.5,
 					NULL
@@ -188,14 +194,14 @@ bool gcpChargeTool::OnClicked()
 		path[0].code = ART_MOVETO_OPEN;
 		path[0].x3 = xc + 1.;
 		path[1].code = ART_LINETO;
-		path[1].x3 = xc + ChargeSignSize - 1.;
-		path[0].y3 = path[1].y3 = yc + ChargeSignSize / 2.;
+		path[1].x3 = xc + Theme->GetChargeSignSize () - 1.;
+		path[0].y3 = path[1].y3 = yc + Theme->GetChargeSignSize () / 2.;
 		if (m_Charge > 0) {
 			path[2].code = ART_MOVETO_OPEN;
 			path[2].y3 = yc + 1.;
 			path[3].code = ART_LINETO;
-			path[3].y3 = yc + ChargeSignSize - 1.;
-			path[2].x3 = path[3].x3 = xc + ChargeSignSize / 2.;
+			path[3].y3 = yc + Theme->GetChargeSignSize () - 1.;
+			path[2].x3 = path[3].x3 = xc + Theme->GetChargeSignSize () / 2.;
 			path[4].code = ART_END;
 		} else
 			path[2].code = ART_END;
@@ -209,6 +215,8 @@ bool gcpChargeTool::OnClicked()
 					NULL
 				);
 		gnome_canvas_path_def_unref (cpd);
+		if (pl)
+			g_object_unref (G_OBJECT (pl));
 	} else {
 		void *child = g_object_get_data (obj, "figure");
 		if (child)
@@ -325,6 +333,7 @@ void gcpChargeTool::OnDrag()
 	} else {
 		double x, y;
 		gcpAtom *pAtom = (gcpAtom*)m_pObject;
+		gcpTheme *Theme = m_pView->GetDoc ()->GetTheme ();
 		if (!(m_nState & GDK_SHIFT_MASK) && (m_dDist >= m_dDistMax) && m_bChanged) {
 			gnome_canvas_item_hide (m_pItem);
 			m_bChanged = false;
@@ -340,21 +349,21 @@ void gcpChargeTool::OnDrag()
 			}
 			switch (align) {
 			case -2:
-				x += m_ChargeTWidth / 2. - ChargeSignSize - 1.;
-				y += ChargeSignHeight / 2.;
+				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
+				y += Theme->GetChargeSignSize () / 2.;
 				break;
 			case -1:
-				x-= ChargeSignSize + 2.;
+				x-= Theme->GetChargeSignSize () + Theme->GetPadding ();
 				break;
 			case -3:
-				x += m_ChargeTWidth / 2. - ChargeSignSize - 1.;
+				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
 				break;
 			case 1:
-				x += m_ChargeWidth + 2.;
+				x += m_ChargeWidth + Theme->GetPadding ();
 				break;
 			case 2:
-				x += m_ChargeTWidth / 2. - ChargeSignSize - 1.;
-				y -= ChargeSignHeight / 2.;
+				x += m_ChargeTWidth / 2. - Theme->GetChargeSignSize () - 1.;
+				y -= Theme->GetChargeSignSize () / 2.;
 				break;
 			}
 			gnome_canvas_item_move (m_pItem, x - m_x1, y - m_y1);
