@@ -4,9 +4,7 @@
  * GChemPaint atoms plugin
  * electrontool.cc 
  *
- * Copyright (C) 2004-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -33,8 +31,8 @@
 #include "lib/operation.h"
 #include "lib/settings.h"
 #include "libgcpcanvas/gcp-canvas-bpath.h"
-#include <glib/gi18n.h>
-#include <math.h>
+#include <glib/gi18n-lib.h>
+#include <cmath>
 #include <stdexcept>
 
 gcpElectronTool::gcpElectronTool (gcpApplication *App, string Id): gcpTool (App, Id)
