@@ -197,8 +197,8 @@ void gcpBondTool::OnDrag()
 		if (pItem == (GnomeCanvasItem*)m_pBackground) pItem = NULL;
 		Object* pObject = NULL;
 		if (pItem) {
-			pObject = (Object*) g_object_get_data(G_OBJECT(pItem), "object");
-			if (pObject == m_pObject || (pObject->GetType() == FragmentType) && dynamic_cast<gcpFragment*>(pObject)->GetAtom () == m_pObject)
+			pObject = (Object*) g_object_get_data(G_OBJECT (pItem), "object");
+			if (pObject && (pObject == m_pObject || (pObject->GetType () == FragmentType && dynamic_cast<gcpFragment*> (pObject)->GetAtom () == m_pObject)))
 				return;
 		}
 		double dAngle;
