@@ -4,7 +4,7 @@
  * GChemPaint bonds plugin
  * bondtool.h 
  *
- * Copyright (C) 2001-2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -40,6 +40,9 @@ public:
 	void OnRelease();
 	GtkWidget *GetPropertyPage ();
 	void Activate ();
+	void SetAngle (double angle);
+	void SetLength (double length);
+	char const *GetHelpTag () {return "bond";}
 
 protected:
 	virtual void Draw();
