@@ -4,7 +4,7 @@
  * GChemPaint bonds plugin
  * chaintool.cc
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -23,7 +23,6 @@
  */
 
 #include "gchempaint-config.h"
-#include <math.h>
 #include "chaintool.h"
 #include "lib/settings.h"
 #include "lib/document.h"
@@ -32,6 +31,7 @@
 #include "lib/bond.h"
 #include "lib/theme.h"
 #include <glib/gi18n-lib.h>
+#include <cmath>
 
 gcpChainTool::gcpChainTool(gcpApplication *App): gcpTool (App, "Chain")
 {
@@ -156,6 +156,8 @@ void gcpChainTool::OnDrag()
 		else if (pObject->GetType () == AtomType)
 			pAtom = (gcpAtom*) pObject;
 	}
+	if (m_pObject && pAtom == m_pObject)
+		return;
 	if (pAtom && MergeAtoms) {
 		// in that case, end the chain there with the current number of bonds
 		pAtom->GetCoords(&m_x, &m_y, NULL);
@@ -239,13 +241,14 @@ void gcpChainTool::OnRelease()
 	char const *Id;
 	gcpMolecule *pMol = NULL;
 	gcpBond* pBond = NULL;
+	m_pApp->ClearStatus();
 	if (m_pItem) {
 		gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (m_pItem), &x1, &y1, &x2, &y2);
 		gtk_object_destroy (GTK_OBJECT(GNOME_CANVAS_ITEM (m_pItem)));
 		gnome_canvas_request_redraw (GNOME_CANVAS (m_pWidget), (int) x1, (int) y1, (int) x2, (int) y2);
 		m_pItem = NULL;
-	}
-	m_pApp->ClearStatus();
+	} else
+		return;
 	if (!m_Allowed)
 		return;
 	for (nb = 0; nb < m_CurPoints; nb++) {
@@ -266,7 +269,7 @@ void gcpChainTool::OnRelease()
 				0);
 			pDoc->AddAtom (m_Atoms[nb]);
 		}
-		if (nb > 0) {
+		if (nb > 0 && m_Atoms[nb] != m_Atoms[nb - 1]) {
 			pBond = reinterpret_cast<gcpBond*> (m_Atoms[nb]->GetBond (m_Atoms[nb - 1]));
 			if (!pBond) {
 				pBond = new gcpBond (m_Atoms[nb - 1], m_Atoms[nb], 1);
@@ -335,7 +338,7 @@ void gcpChainTool::SetLength (double length)
 
 GtkWidget *gcpChainTool::GetPropertyPage ()
 {
-	GladeXML *xml = glade_xml_new (DATADIR"/gchempaint-unstable/ui/chain.glade", "chain", GETTEXT_PACKAGE);
+	GladeXML *xml = glade_xml_new (GLADEDIR"/chain.glade", "chain", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_AngleBtn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "bond-angle"));
