@@ -27,7 +27,6 @@
 #include "lib/application.h"
 #include "bondtool.h"
 #include "chaintool.h"
-#include "delocalizedtool.h"
 #include "gcp-stock-pixbufs.h"
 #include <glib/gi18n-lib.h>
 
@@ -48,7 +47,6 @@ static gcpIconDesc icon_descs[] = {
 	{"gcp_DownBond", gcp_downbond_24},
 	{"gcp_XBond", gcp_xbond_24},
 	{"gcp_ForeBond", gcp_forebond_24},
-	{"gcp_DelocalizedBond", gcp_delocalizedbond_24},
 	{NULL, NULL},
 };
 
@@ -71,9 +69,6 @@ static GtkRadioActionEntry entries[] = {
 	{	"ForeBond", "gcp_ForeBond", N_("Fore bond tool"), NULL,
 		N_("Add a fore bond"),
 		0	},
-	{	"DelocalizedBond", "gcp_DelocalizedBond", N_("Delocalized bond tool"), NULL,
-		N_("Add a delocalized bonds system"),
-		0	},
 };
 
 static const char *ui_description =
@@ -85,7 +80,6 @@ static const char *ui_description =
 "    <toolitem action='DownBond'/>"
 "    <toolitem action='SquiggleBond'/>"
 "    <toolitem action='ForeBond'/>"
-//"    <toolitem action='DelocalizedBond'/>"
 "  </toolbar>"
 "</ui>";
 
@@ -99,5 +93,4 @@ void gcpBondsPlugin::Populate (gcpApplication* App)
 	new gcpDownBondTool (App);
 	new gcpForeBondTool (App);
 	new gcpSquiggleBondTool (App);
-	new gcpDelocalizedTool (App);
 }
