@@ -4,7 +4,7 @@
  * GChemPaint cycles plugin
  * cycletool.h 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -43,7 +43,8 @@ public:
 	GtkWidget *GetPropertyPage ();
 	void Activate ();
 	void SetLength (double length);
-	
+	char const *GetHelpTag () {return "cycle";}
+
 protected:
 	void Init();
 	bool CheckIfAllowed();
@@ -72,7 +73,6 @@ public:
 
 	void SetSize(unsigned char size);
 	unsigned char GetSize() {return m_size;}
-	void SetOptions();
 	GtkWidget *GetPropertyPage ();
 
 private:
