@@ -33,7 +33,7 @@
 #include "lib/theme.h"
 #include "lib/window.h"
 #include <glib/gi18n-lib.h>
-#include <math.h>
+#include <cmath>
 #include <stdexcept>
 
 static void on_flip(GtkWidget *btn, gcpApplication* App)
@@ -214,13 +214,10 @@ void gcpSelectionTool::OnRelease()
 		else m_y1 = m_y;
 		double x0, y0, x1, y1;
 		std::map<Object*, GnomeCanvasGroup*>::iterator j;
-		for (j = m_pData->Items.begin(); j != m_pData->Items.end(); j++)
-		{
-			if (!m_pData->IsSelected((*j).first))
-			{
+		for (j = m_pData->Items.begin (); j != m_pData->Items.end (); j++) {
+			if (!m_pData->IsSelected ((*j).first)) {
 				gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM((*j).second), &x0, &y0,&x1, &y1);
-				if ((x0 < m_x1) && (y0 < m_y1) && (x1 > m_x0) && (y1 > m_y0))
-				{
+				if ((x0 < m_x1) && (y0 < m_y1) && (x1 > m_x0) && (y1 > m_y0)) {
 					m_pObject = (*j).first->GetGroup ();	//GetMolecule();
 					if (m_pObject) {
 						if (!m_pData->IsSelected(m_pObject))
