@@ -4,7 +4,7 @@
  * GChemPaint templates plugin
  * templatetool.h 
  *
- * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,6 +28,7 @@
 #include "lib/tool.h"
 
 class gcpTemplate;
+class gcpDocument;
 
 class gcpTemplateTool: public gcpTool
 {
@@ -38,12 +39,18 @@ public:
 	virtual bool OnClicked();
 	virtual void OnDrag();
 	virtual void OnRelease();
-	virtual void SetOptions();
-	void SetTemplate (gcpTemplate* temp);
 	gcpTemplate* GetTemplate () {return m_Template;}
+	GtkWidget *GetPropertyPage ();
+	void OnChanged(GtkComboBox *combo);
+	void OnPreviewSize (GtkAllocation *allocation);
+	void OnAddTemplate ();
+	void OnDeleteTemplate ();
+	char const *GetHelpTag () {return "templates";}
 
 private:
 	gcpTemplate* m_Template;
+	GtkWidget *m_DeleteBtn;
+	GtkNotebook *m_Book;
 };
 
 #endif //GCHEMPAINT_TEMPLATETOOL_H
