@@ -4,7 +4,7 @@
  * GChemPaint
  * main.cc 
  *
- * Copyright (C) 2001-2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -35,10 +35,6 @@ extern "C" {
 	void gnome_authentication_manager_init ();
 }
 
-#warning "the following lines should be removed for stable releases"
-#undef PACKAGE
-#define PACKAGE "gchempaint-unstable" 
-
 void cb_print_version (const gchar *option_name, const gchar *value, gpointer data, GError **error)
 {
 	char *version = g_strconcat (_("GChemPaint version: "), VERSION, NULL);
@@ -58,10 +54,6 @@ int main(int argc, char *argv[])
 {
 	GOptionContext *context;
 	GError *error = NULL;
-	bindtextdomain(GETTEXT_PACKAGE, DATADIR"/locale");
-#ifdef ENABLE_NLS
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
 	textdomain(GETTEXT_PACKAGE);
 
 	gtk_init (&argc, &argv);
