@@ -4,7 +4,7 @@
  * GChemPaint
  * standaloneapp.cc
  *
- * Copyright (C) 2004-2005 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2007 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -25,6 +25,7 @@
 #include "gchempaint-config.h"
 #include "standaloneapp.h"
 #include "standalonewin.h"
+#include <glib/gi18n-lib.h>
 
 gcpStandaloneApp::gcpStandaloneApp(): gcpApplication()
 {
@@ -36,14 +37,14 @@ gcpStandaloneApp::~gcpStandaloneApp()
 		delete *m_Docs.begin();
 }
 
-void gcpStandaloneApp::OnFileNew()
+void gcpStandaloneApp::OnFileNew(char const *Theme)
 {
 	gchar tmp[32];
 	if (m_pActiveDoc && !m_pActiveDoc->GetView ()->PrepareUnselect ())
 		return;
 	g_snprintf (tmp, sizeof (tmp), _("Untitled %d"), m_NumWindow++);
-	gcpWindow *win = new gcpStandaloneWindow (this);
-	win->SetTitle (tmp);
+	gcpWindow *win = new gcpStandaloneWindow (this, Theme);
+	win->GetDocument ()->SetLabel (tmp);
 }
 
 GtkWindow* gcpStandaloneApp::GetWindow()
